package com.qq.e.demo;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.View.OnTouchListener;
import android.webkit.CookieSyncManager;
import android.widget.Button;

import com.qq.e.ads.InterstitialAd;
import com.qq.e.ads.InterstitialAdListener;
import com.qq.e.appwall.GdtAppwall;
import com.qq.e.gridappwall.GridAppWall;
import com.qq.e.gridappwall.GridAppWallListener;

public class MainDemoActivity extends Activity {

  private InterstitialAd iad;

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.activity_main_demo);
    CookieSyncManager.createInstance(this);
    bindBannerADButton();
    bindInterstitialAdButton();
    bindAppWallButton();
    bindSplashButton();
    bindGridWallButton();
    bindFeedsButton();
  }

  private void bindGridWallButton() {
    View gridButton = this.findViewById(R.id.imageButton1);
    final int screenWidth = this.getResources().getDisplayMetrics().widthPixels;
    final int screenHeight = this.getResources().getDisplayMetrics().heightPixels;
    gridButton.setOnTouchListener(new OnTouchListener() {
      private int lastX, lastY, initX, initY;

      public boolean onTouch(View v, MotionEvent event) {
        int ea = event.getAction();
        switch (ea) {
          case MotionEvent.ACTION_DOWN:
            lastX = (int) event.getRawX();
            lastY = (int) event.getRawY();
            initX = lastX;
            initY = lastY;
            break;
          case MotionEvent.ACTION_MOVE: // 移动
            // 移动中动态设置位置
            int dx = (int) event.getRawX() - lastX;
            int dy = (int) event.getRawY() - lastY;
            int left = v.getLeft() + dx;
            int top = v.getTop() + dy;
            int right = v.getRight() + dx;
            int bottom = v.getBottom() + dy;
            if (left < 0) {
              left = 0;
              right = left + v.getWidth();
            }
            if (right > screenWidth) {
              right = screenWidth;
              left = right - v.getWidth();
            }
            if (top < 0) {
              top = 0;
              bottom = top + v.getHeight();
            }
            if (bottom > screenHeight) {
              bottom = screenHeight;
              top = bottom - v.getHeight();
            }
            v.layout(left, top, right, bottom);
            lastX = (int) event.getRawX();
            lastY = (int) event.getRawY();
            break;
          case MotionEvent.ACTION_UP: // 脱离
            int x = (int) event.getRawX();
            int y = (int) event.getRawY();
            if (Math.abs(x - initX) > 10 || Math.abs(y - initY) > 10) {
              return true;
            }
            break;
        }
        return false;
      }

    });

    gridButton.setOnClickListener(new OnClickListener() {

      @Override
      public void onClick(View view) {
        GridAppWall gw =
            new GridAppWall(Constants.APPId, Constants.GridAppWallPosId, MainDemoActivity.this,
                new GridAppWallListener() {

                  @Override
                  public void onAdPresent() {
                    Log.i("Demo", "Grid Present");
                  }

                  @Override
                  public void onAdFailed(int arg0) {
                    Log.i("Demo", "Grid Fail");
                  }

                  @Override
                  public void onAdDismissed() {
                    Log.i("Demo", "Grid Dismissed");
                  }
                });
        gw.showRelativeTo(view);
      }
    });
  }

  private void bindBannerADButton() {
    Button showBannerButton = (Button) this.findViewById(R.id.showBannerButton);
    showBannerButton.setOnClickListener(new OnClickListener() {

      @Override
      public void onClick(View v) {
        Intent intent = new Intent();
        intent.setClass(MainDemoActivity.this, BannerDemoActivity.class);
        MainDemoActivity.this.startActivity(intent);
      }
    });
  }

  private void bindInterstitialAdButton() {
    iad = new InterstitialAd(this, Constants.APPId, Constants.InterteristalPosId);
    iad.setAdListener(new InterstitialAdListener() {
      @Override
      public void onBack() {
        // iad.loadAd();
      }

      @Override
      public void onFail() {

      }

      @Override
      public void onAdReceive() {
        Log.i("admsg:", "receive ad pic");

        iad.show(MainDemoActivity.this);
      }
    });
    Button interstitialAdButton = (Button) findViewById(R.id.showInterstitialAdButton);
    interstitialAdButton.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View v) {
        iad.loadAd();
      }
    });
  }

  private void bindAppWallButton() {
    Button showWallButton = (Button) this.findViewById(R.id.showAppWallButton);
    showWallButton.setOnClickListener(new OnClickListener() {

      @Override
      public void onClick(View v) {
        GdtAppwall wall =
            new GdtAppwall(MainDemoActivity.this, Constants.APPId, Constants.APPWallPosId, false);
        wall.doShowAppWall();
      }
    });
  }

  private void bindSplashButton() {
    Button splashButton = (Button) this.findViewById(R.id.splashButton);
    splashButton.setOnClickListener(new OnClickListener() {

      @Override
      public void onClick(View v) {
        Intent intent = new Intent(MainDemoActivity.this, FullscreenActivity.class);
        MainDemoActivity.this.startActivity(intent);
      }
    });
  }

  @Override
  public boolean onCreateOptionsMenu(Menu menu) {
    return true;
  }

  private void bindFeedsButton() {
    Button feedsButton = (Button) this.findViewById(R.id.feedsButton);
    feedsButton.setOnClickListener(new OnClickListener() {
      @Override
      public void onClick(View v) {
        Intent intent = new Intent();
        intent.setClass(MainDemoActivity.this, StandardFeedsDemoActivity.class);
        MainDemoActivity.this.startActivity(intent);
      }
    });
    Button feedsButtonAdvanced = (Button) this.findViewById(R.id.feedsButtonAdvanced);
    feedsButtonAdvanced.setOnClickListener(new OnClickListener() {
      
      @Override
      public void onClick(View v) {
        Intent intent = new Intent();
        intent.setClass(MainDemoActivity.this, CustomFeedsDemoActivity.class);
        MainDemoActivity.this.startActivity(intent);
      }
    });
  }
}
