package com.qq.e.demo;

import android.annotation.SuppressLint;
import android.content.Context;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.ViewTreeObserver.OnGlobalLayoutListener;
import android.view.animation.DecelerateInterpolator;
import android.widget.AbsListView;
import android.widget.AbsListView.OnScrollListener;
import android.widget.ListView;
import android.widget.RelativeLayout;
import android.widget.Scroller;

import com.qq.e.demo.PulldownListViewHeader.State;

public class PulldownListView extends ListView implements OnScrollListener {

  private float lastY = -1;
  private PulldownListViewHeader header;
  private RelativeLayout headerContent;
  private int headerHeight;
  private OnRefreshListener refreshListener;
  private boolean pullRefreshing = false;

  // 用于下拉时回滚
  private Scroller scroller;

  private final static int SCROLL_DURATION = 400;
  private final static float OFFSET_RADIO = 1.8f;

  public interface OnRefreshListener {
    public void onRefresh();
  }

  public PulldownListView(Context context) {
    super(context);
    init(context);
  }

  public PulldownListView(Context context, AttributeSet attrs) {
    super(context, attrs);
    init(context);
  }

  private void init(Context context) {
    scroller = new Scroller(context, new DecelerateInterpolator());
    setOnScrollListener(this);

    header = new PulldownListViewHeader(context);
    headerContent = (RelativeLayout) header.findViewById(R.id.head_content);
    addHeaderView(header);

    header.getViewTreeObserver().addOnGlobalLayoutListener(new OnGlobalLayoutListener() {
      @SuppressWarnings("deprecation")
      @Override
      public void onGlobalLayout() {
        headerHeight = headerContent.getHeight();
        getViewTreeObserver().removeGlobalOnLayoutListener(this);
      }
    });
  }

  @Override
  public void onScroll(AbsListView arg0, int arg1, int arg2, int arg3) {
    // TODO Auto-generated method stub
  }

  @Override
  public void onScrollStateChanged(AbsListView arg0, int arg1) {
    // TODO Auto-generated method stub
  }

  public void setOnRefreshListener(OnRefreshListener l) {
    refreshListener = l;
  }

  @SuppressLint("SimpleDateFormat")
  public void stopRefresh() {
    if (pullRefreshing == true) {
      pullRefreshing = false;
      resetHeaderHeight();
      header.updateRefreshTime();
    }
  }

  @Override
  public boolean onTouchEvent(MotionEvent ev) {
    if (lastY == -1) {
      lastY = ev.getRawY();
    }

    switch (ev.getAction()) {
      case MotionEvent.ACTION_DOWN:
        lastY = ev.getRawY();
        break;
      case MotionEvent.ACTION_MOVE:
        final float deltaY = ev.getRawY() - lastY;
        lastY = ev.getRawY();
        if (getFirstVisiblePosition() == 0 && (header.getVisiableHeight() > 0 || deltaY > 0)) {
          // 当屏幕中 第一个可见元素是listview的第一个元素时，显示 headerview
          updateHeaderHeight(deltaY / OFFSET_RADIO);
        }
        break;
      default:
        lastY = -1; 
        if (getFirstVisiblePosition() == 0) {
          if (header.getVisiableHeight() > headerHeight) {
            pullRefreshing = true;
            header.setState(State.REFRESHING);
            if (refreshListener != null) {
              refreshListener.onRefresh();
            }
          }
          resetHeaderHeight();
        }
        break;
    }
    return super.onTouchEvent(ev);
  }

  @Override
  public void computeScroll() {
    if (scroller.computeScrollOffset()) {
      header.setVisiableHeight(scroller.getCurrY());
      postInvalidate();
    }
    super.computeScroll();
  }

  private void updateHeaderHeight(float delta) {
    header.setVisiableHeight((int) delta + header.getVisiableHeight());
    if (!pullRefreshing) {
      // 未处于刷新状态，更新箭头
      if (header.getVisiableHeight() > headerHeight) {
        header.setState(State.PULL_READY);
      } else {
        header.setState(State.PULL_START);
      }
    }
    setSelection(0);
  }

  private void resetHeaderHeight() {
    int height = header.getVisiableHeight();
    if (height == 0) return;
    
    if (pullRefreshing && height <= headerHeight) {
      return;
    }
    int finalHeight = 0;
    if (pullRefreshing && height > headerHeight) {
      finalHeight = headerHeight;
    }

    scroller.startScroll(0, height, 0, finalHeight - height, SCROLL_DURATION);

    invalidate();
  }
}
