package com.qq.e.demo;

import java.text.SimpleDateFormat;
import java.util.Date;

import android.content.Context;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.RotateAnimation;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ProgressBar;
import android.widget.TextView;

public class PulldownListViewHeader extends LinearLayout {

  public enum State {
    PULL_START, REFRESHING, PULL_READY
  }

  private LinearLayout container;
  private ImageView arrowImageView;
  private ProgressBar progressBar;
  private TextView tipsTextView;
  private TextView lastUpdateTextView;
  private State state = State.PULL_START;

  private Animation rotateUp;
  private Animation rotateDown;

  private final int ROTATE_ANIM_DURATION = 180;

  public PulldownListViewHeader(Context context) {
    super(context);
    init(context);
  }

  private void init(Context context) {
    LinearLayout.LayoutParams lp = new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, 0);
    container = (LinearLayout) LayoutInflater.from(context).inflate(R.layout.pulldown_header, null);
    addView(container, lp);
    setGravity(Gravity.BOTTOM);

    arrowImageView = (ImageView) findViewById(R.id.head_arrow);
    progressBar = (ProgressBar) findViewById(R.id.head_progressbar);
    tipsTextView = (TextView) findViewById(R.id.head_tips);
    lastUpdateTextView = (TextView) findViewById(R.id.head_lastUpdated);
    updateRefreshTime();

    rotateUp =
        new RotateAnimation(0.0f, -180.0f, Animation.RELATIVE_TO_SELF, 0.5f,
            Animation.RELATIVE_TO_SELF, 0.5f);
    rotateUp.setDuration(ROTATE_ANIM_DURATION);
    rotateUp.setFillAfter(true);
    rotateDown =
        new RotateAnimation(-180.0f, 0.0f, Animation.RELATIVE_TO_SELF, 0.5f,
            Animation.RELATIVE_TO_SELF, 0.5f);
    rotateDown.setDuration(ROTATE_ANIM_DURATION);
    rotateDown.setFillAfter(true);
  }

  public void setState(State newState) {
    if (newState == state) return;

    if (newState == State.REFRESHING) {
      // 正在刷新
      arrowImageView.clearAnimation();
      arrowImageView.setVisibility(View.INVISIBLE);
      progressBar.setVisibility(View.VISIBLE);
    } else {
      arrowImageView.setVisibility(View.VISIBLE);
      progressBar.setVisibility(View.INVISIBLE);
    }

    switch (newState) {
      case PULL_START:
        if (state == State.PULL_READY) {
          arrowImageView.startAnimation(rotateDown);
        }
        if (state == State.REFRESHING) {
          arrowImageView.clearAnimation();
        }
        tipsTextView.setText("下拉刷新");
        break;
      case PULL_READY:
        if (state != State.PULL_READY) {
          arrowImageView.clearAnimation();
          arrowImageView.startAnimation(rotateUp);
          tipsTextView.setText("松开刷新数据");
        }
        break;
      case REFRESHING:
        tipsTextView.setText("正在加载...");
        break;
      default:
    }

    state = newState;
  }

  public void setVisiableHeight(int height) {
    if (height < 0) height = 0;
    LinearLayout.LayoutParams lp = (LinearLayout.LayoutParams) container.getLayoutParams();
    lp.height = height;
    container.setLayoutParams(lp);
  }

  public int getVisiableHeight() {
    return container.getHeight();
  }

  public void updateRefreshTime() {
    SimpleDateFormat format = new SimpleDateFormat("yyyy年MM月dd日  HH:mm");
    String date = format.format(new Date());
    lastUpdateTextView.setText("最近更新:" + date);
  }
}
