package com.qq.e.demo.feeds;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import android.content.Context;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.qq.e.demo.R;
import com.qq.e.feedsad.FeedsADViewRef;

public abstract class BaseFeedsDemoAdapter extends BaseAdapter {
  private List<FeedsItem> data;
  private List<FeedsADItem> adList;// 用来快速访问所有的ADView

  protected LayoutInflater inflater;
  protected Context context;

  public BaseFeedsDemoAdapter(Context context, List<FeedsItem> data) {
    this.data = data;
    this.setAdList(new ArrayList<FeedsADItem>());
    this.inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
    this.context = context;
  }

  @Override
  public int getItemViewType(int position) {
    return data.get(position) instanceof FeedsADItem ? 0 : 1;
  }

  @Override
  public int getViewTypeCount() {
    return 2;
  }

  @Override
  public int getCount() {
    return data.size();
  }

  @Override
  public Object getItem(int position) {
    return data.get(position);
  }

  @Override
  public long getItemId(int position) {
    return position;
  }


  @Override
  public View getView(int position, View convertView, ViewGroup parent) {
    if (convertView != null) {
      Log.i("Test", "convertView class:" + convertView.getClass() + ", convertView:" + convertView);
    } else {
      Log.i("Test", "convertView is null");
    }
    FeedsItem item = data.get(position);
    if (item instanceof FeedsADItem) {
      FeedsADItem ad = (FeedsADItem) item;
      return getViewFor(ad, convertView, parent);
    } else {
      return getViewFor(item, convertView, parent);
    }
  }
  
  protected abstract View getViewFor(FeedsADItem adData, View convertView, View parent);


  protected View getViewFor(FeedsItem data, View convertView, View parent) {
    if (convertView != null) {
      if (convertView instanceof RelativeLayout) {
        RelativeLayout layout = (RelativeLayout) convertView;
        TextView txt = (TextView) layout.findViewById(R.id.jokeName);
        if (txt != null) {
          txt.setText(data.getName());
          return layout;
        }
      }
    }
    RelativeLayout layout = (RelativeLayout) inflater.inflate(R.layout.jokeitem, null);
    TextView txt = (TextView) layout.findViewById(R.id.jokeName);
    txt.setText(data.getName());
    return layout;
  }

  public void addNormal(int n) {
    if (n <= 0) {
      return;
    }
    int s = data.size();
    for (int i = s; i < s + n; i++) {
      FeedsItem it = new FeedsItem();
      if (i % 2 == 0) {
        it.setName(i + "：失联客机最后通话披露 我国扩大搜救范围");
      } else {
        it.setName(i
            + "：[摘要]马方披露失联客机最后通话内容，马方塔台称“已把你们交接给胡志明市管辖区”，航班回“好的收到”。我国搜救范围扩至马六甲海峡，协调商船协助搜救。");
      }
      data.add(0, it);
    }
  }

  public void addAD(FeedsADViewRef v) {
    FeedsADItem it = new FeedsADItem();
    it.setName("Ad view" + data.size());
    it.setRef(v);
    this.getAdList().add(it);
    data.add(0, it);
  }

  public void addAD(Collection<com.qq.e.feedsad.FeedsADViewRef> refs) {
    int i = 0;
    for (FeedsADViewRef ref : refs) {
      FeedsADItem it = new FeedsADItem();
      it.setName("Ad view" + data.size());
      it.setRef(ref);
      int index = Math.min((++i)*6, this.getCount());
      this.getAdList().add(it);
      data.add(index, it);
    }
    this.notifyDataSetChanged();
  }

  public List<FeedsADItem> getAdList() {
    return adList;
  }

  public void setAdList(List<FeedsADItem> adList) {
    this.adList = adList;
  }
}
